==> jc-1.4.0.tar.gz: polyglot/ext/jl/types/TypeSystem__5fc__24MostSpecificComparator.h <==
// public class polyglot.ext.jl.types.TypeSystem_c$MostSpecificComparator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4a3370a0dd8fbb6 polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator_H_
#define _JC_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_refs	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_refs;
typedef struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_nonrefs	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$refs	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$refs;
typedef struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$nonrefs	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$nonrefs;
typedef struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$object	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$object;

typedef const struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vmethods	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vmethods;
typedef const struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtable	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtable;
typedef const struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtype	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$method$_init$fb0374e074e12f0c(_jc_env *, struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$object *, struct _jc_polyglot_ext_jl_types_TypeSystem__5fc$object *);

// Virtual methods
extern jint _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vmethods	polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator;
};

// Vtype
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_refs {
	struct _jc_polyglot_ext_jl_types_TypeSystem__5fc$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$refs {
    _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_refs	polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_nonrefs	polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator;
};

// Object instance structure
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$object {
	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtype	*vtype;
	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtype _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$class_object;

#endif	/* _JC_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/types/TypeSystem__5fc__24MostSpecificComparator.h <==
// public class polyglot.ext.jl.types.TypeSystem_c$MostSpecificComparator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4a3370a0dd8fbb6 polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator_H_
#define _JC_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_refs	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_refs;
typedef struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_nonrefs	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$refs	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$refs;
typedef struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$nonrefs	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$nonrefs;
typedef struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$object	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$object;

typedef const struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vmethods	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vmethods;
typedef const struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtable	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtable;
typedef const struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtype	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$method$_init$fb0374e074e12f0c(_jc_env *, struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$object *, struct _jc_polyglot_ext_jl_types_TypeSystem__5fc$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vmethods	polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator;
};

// Vtype
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_refs {
	struct _jc_polyglot_ext_jl_types_TypeSystem__5fc$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$refs {
    _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_refs	polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$sub_nonrefs	polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator;
};

// Object instance structure
struct _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$object {
	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtype	*vtype;
	_jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$vtype _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator$class_object;

#endif	/* _JC_polyglot_ext_jl_types_TypeSystem__5fc__24MostSpecificComparator_H_ */
